@@ -3,11 +3,21 @@
 #
 # Copyright (C) 2008 Hasiotis Nikos
 #
-# ID: $Id: SDNP.pm 76 2009-04-02 20:55:44Z hasiotis $
+# ID: $Id: SDNP.pm 88 2009-04-08 15:21:04Z hasiotis $
 
 package EAFDSS::SDNP;
 
-use 5.006001;
+=head1 NAME
+
+EAFDSS::SDNP - EAFDSS Driver for Micrelec SDNP Devices
+
+=head1 DESCRIPTION
+
+Read EAFDSS on how to use the module.
+
+=cut
+
+use 5.6.0;
 use strict;
 use warnings;
 use POSIX;
@@ -19,7 +29,7 @@ use IO::Socket::INET;
 
 use base qw (EAFDSS::Micrelec );
 
-our($VERSION) = '0.40';
+our($VERSION) = '0.60';
 
 my($clock_ticks);
 if ( $^O =~ /MSWin32/ ) {
@@ -29,6 +39,12 @@ if ( $^O =~ /MSWin32/ ) {
 }
 
 
+=head2 init
+
+init
+
+=cut
+
 sub init {
 	my($class)  = shift @_;
 	my($config) = @_;
@@ -66,6 +82,12 @@ sub init {
 	return $self;
 }
 
+=head2 SendRequest
+
+SendRequest
+
+=cut
+
 sub SendRequest {
 	my($self)   = shift @_;
 	my($opcode) = shift @_;
@@ -525,18 +547,10 @@ sub _getTimer {
 1;
 __END__
 
-=head1 NAME
-
-EAFDSS::SDNP - EAFDSS Driver for Micrelec SDNP Devices
-
-
-=head1 DESCRIPTION
-
-Read EAFDSS on how to use the module.
 
 =head1 VERSION
 
-This is version 0.40.
+This is version 0.60.
 
 =head1 AUTHOR
 
